import requests
import xml.etree.ElementTree as ET

def download_xml(url):
    response = requests.get(url)
    if response.status_code == 200:
        return response.content
    else:
        raise Exception(f"Failed to download XML. Status code: {response.status_code}")

def parse_xml(xml_content):
    root = ET.fromstring(xml_content)
    entries = root.findall('.//entry')

    playlist_entries = []

    for entry in entries:
        server_name = entry.find('server_name').text
        listen_url = entry.find('listen_url').text

        playlist_entries.append(f"#EXTINF:-1,{server_name}\n{listen_url}\n")

    return playlist_entries

def write_to_m3u(playlist_entries, output_file):
    with open(output_file, 'w', encoding='utf-8') as file:
        file.write('#EXTM3U\n')
        file.writelines(playlist_entries)

if __name__ == "__main__":
    xml_url = 'http://dir.xiph.org/yp.xml'  # Tutaj podaj adres URL do pliku XML
    output_file = 'icecasty.m3u'

    xml_content = download_xml(xml_url)
    playlist_entries = parse_xml(xml_content)
    write_to_m3u(playlist_entries, output_file)
